@@ -4,9 +4,6 @@
  * Provides single sign-on functionality via API keys
  */
 
-// Log that PHP is executing
-error_log("SSO API - PHP script started executing");
-
 header('Content-Type: application/json');
 header('Access-Control-Allow-Origin: *'); // Configure appropriately for production
 header('Access-Control-Allow-Methods: POST, OPTIONS');
@@ -14,26 +11,17 @@ header('Access-Control-Allow-Headers: Content-Type, X-API-Key, X-API-Secret, Aut
 
 // Handle preflight requests
 if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
-    error_log("SSO API - OPTIONS request received");
     exit(0);
 }
 
-error_log("SSO API - About to include required files");
 require_once(__DIR__ . '/../../libs/api_auth.php');
 require_once(__DIR__ . '/../../libs/ApiKeyManager.php');
 require_once(__DIR__ . '/../../libs/network.php');
-error_log("SSO API - Required files included successfully");
 
 try {
     // Store raw input early since php://input can only be read once
     $rawRequestBody = file_get_contents('php://input');
     
-    // Debug incoming request
-    error_log("SSO API Request - Method: " . $_SERVER['REQUEST_METHOD']);
-    error_log("SSO API Request - Headers: " . json_encode(getallheaders()));
-    error_log("SSO API Request - GET params: " . json_encode($_GET));
-    error_log("SSO API Request - Raw body: " . $rawRequestBody);
-    
     // Authenticate and check permissions
     $authData = api_authenticate('sso_access');
     
@@ -72,9 +60,6 @@ function handlePostRequest($action, $authData, $rawRequestBody) {
 function generateSSOToken($authData, $rawInput) {
     $input = json_decode($rawInput, true);
     
-    // Enhanced logging for debugging
-    error_log("SSO Token Request - Raw input: " . $rawInput);
-    error_log("SSO Token Request - Parsed input: " . json_encode($input));
     
     if (!$input) {
         api_response(false, null, 'Invalid JSON input', 400);
@@ -91,7 +76,6 @@ function generateSSOToken($authData, $rawInput) {
     $redirectUrl = $input['redirect_url'] ?? null;
     $expiryMinutes = intval($input['expiry_minutes'] ?? 10);
     
-    error_log("SSO Token Request - Username: $username, Redirect: $redirectUrl, Expiry: $expiryMinutes");
     
     // Validate expiry time (1-60 minutes)
     if ($expiryMinutes < 1 || $expiryMinutes > 60) {
@@ -102,14 +86,11 @@ function generateSSOToken($authData, $rawInput) {
     require_once(__DIR__ . '/../../libs/usermgmt.php');
     $userMgmt = new usermgmt();
     
-    error_log("SSO Token Request - Checking if user '$username' exists...");
     
     if (!$userMgmt->user_exists($username)) {
-        error_log("SSO Token Request - User '$username' does not exist");
         api_response(false, null, 'User does not exist', 404);
     }
     
-    error_log("SSO Token Request - User '$username' exists, generating token...");
     
     // Generate SSO token
     $apiKeyManager = new ApiKeyManager();
@@ -124,17 +105,14 @@ function generateSSOToken($authData, $rawInput) {
         $expiryMinutes
     );
     
-    error_log("SSO Token Request - Token generation result: " . json_encode($result));
     
     if ($result['success']) {
         // Add full login URL with the site's base URL
         $baseUrl = getBaseUrl();
         $result['login_url'] = $baseUrl . '/api/sso-login.php?token=' . $result['token'];
         
-        error_log("SSO Token Request - SUCCESS - Login URL: " . $result['login_url']);
         api_response(true, $result, 'SSO token generated successfully');
     } else {
-        error_log("SSO Token Request - FAILED - Error: " . $result['error']);
         api_response(false, null, $result['error'], 500);
     }
 }
